# ############
# GroupModel 
# ############
GroupModel.addNew = INSERT INTO jforum_groups (group_id, group_name, group_description, parent_id) VALUES ('jforum_groups_seq'.NEXTVAL, ?, ?, ?)
GroupModel.canDelete = SELECT COUNT(user_id) AS total FROM jforum_user_groups WHERE group_id = ?

# #############
# CategoryModel
# #############
CategoryModel.addNew = INSERT INTO jforum_categories (categories_id, title, display_order, moderated) VALUES ('jforum_categories_seq'.NEXTVAL, ?, ?, ?)
CategoryModel.canDelete = SELECT COUNT(forum_id) AS total FROM jforum_forums WHERE categories_id = ?

# #############
# RankingModel
# #############
RankingModel.addNew = INSERT INTO jforum_ranks (rank_id, rank_title, rank_min, rank_special) VALUES ('jforum_ranks_seq'.NEXTVAL, ?, ?, ? )

# #############
# ConfigModel
# #############
ConfigModel.insert = INSERT INTO jforum_config (config_name, config_value, config_id) VALUES (?, ?, 'jforum_config_seq'.NEXTVAL)

# ##########
# UserModel
# ##########
UserModel.lastGeneratedUserId = SELECT FIRST 1 'jforum_users_seq'.CURRVAL FROM jforum_users

# param : count+startFrom
UserModel.selectAllByLimit = SELECT FIRST #N# user_email, user_id, user_posts, user_regdate, username, deleted, user_karma, \
	user_from, user_website, user_viewemail FROM jforum_users ORDER BY user_id

UserModel.selectAllByGroup = SELECT FIRST #N# user_email, u.user_id, user_posts, user_regdate, username, deleted, \
			user_karma, user_from, user_website, user_viewemail \
			FROM jforum_users u, jforum_user_groups ug \
			WHERE u.user_id = ug.user_id \
			AND ug.group_id = ? \
			ORDER BY user_id ASC

UserModel.addNew = INSERT INTO jforum_users (user_id, username, user_password, user_email, user_regdate, user_actkey) VALUES ('jforum_users_seq'.NEXTVAL, ?, ?, ?, ?, ?)
UserModel.totalUsersByGroup = SELECT COUNT(user_id) FROM jforum_user_groups WHERE group_id = ?
UserModel.totalUsers = SELECT COUNT(user_id) as total_users FROM jforum_users
UserModel.isUsernameRegistered = SELECT COUNT(user_id) as registered FROM jforum_users WHERE LOWER(username) = LOWER(?)
UserModel.validateLostPasswordHash = SELECT COUNT(user_id) AS valid FROM jforum_users WHERE security_hash = ? AND user_email = ?
UserModel.validateActivationKeyHash = SELECT COUNT(user_id) AS valid FROM jforum_users WHERE user_actkey = ? AND user_id = ?
UserModel.lastUserRegistered = SELECT FIRST 1 user_id, username FROM jforum_users ORDER BY user_regdate DESC
UserModel.selectById = SELECT u.*, \
	(SELECT COUNT(pm.privmsgs_to_userid) FROM jforum_privmsgs pm \
	WHERE pm.privmsgs_to_userid = u.user_id \
	AND pm.privmsgs_type = 1) AS private_messages \
	FROM jforum_users u \
	WHERE u.user_id = ?

UserRequestModel.selectAllByForumByLimit = SELECT FIRST #N# user_request_email, user_request_id, firstname, lastname FROM jforum_user_requests \

	WHERE user_request_active = 1 AND forum_id = ? ORDER BY user_request_id

UserRequestModel.lastGeneratedUserId = SELECT FIRST 1 'jforum_user_requests_seq'.CURRVAL FROM jforum_user_requests
UserRequestModel.addNew = INSERT INTO jforum_user_requests (user_request_id, firstname, lastname, user_request_password, user_request_email, user_request_actkey, forum_id) VALUES ('jforum_user_requests_seq'.NEXTVAL, ?, ?, ?, ?, ?, ?)
UserRequestModel.validateActivationKeyHash = SELECT COUNT(user_request_id) AS valid FROM jforum_user_requests WHERE user_request_actkey = ? AND user_request_id = ?


# #############
# PostModel
# #############
PostModel.lastGeneratedPostId = SELECT FIRST 1 'jforum_posts_seq'.CURRVAL FROM jforum_posts

PostModel.addNewPost = INSERT INTO jforum_posts (post_id, topic_id, forum_id, user_id, post_time, poster_ip, enable_bbcode, enable_html, enable_smilies, enable_sig, post_edit_time, need_moderate) \
	VALUES ('jforum_posts_seq'.NEXTVAL, ?, ?, ?, ?, ?, ?, ?, ?, ?, CURRENT YEAR TO SECOND, ?)

PostModel.selectAllByTopicByLimit = SELECT FIRST #N# p.post_id, topic_id, forum_id, p.user_id, post_time, poster_ip, \
			enable_bbcode, p.attach, enable_html, enable_smilies, enable_sig, post_edit_time, \
			post_edit_count, status, pt.post_subject, pt.post_text, username, p.need_moderate \
			FROM jforum_posts p, jforum_posts_text pt, jforum_users u \
			WHERE p.post_id = pt.post_id \
			AND topic_id = ? \
			AND p.user_id = u.user_id \
			AND p.need_moderate = 0 \
			ORDER BY post_time ASC

PostModel.selectByUserByLimit = SELECT FIRST #N# p.post_id, topic_id, forum_id, p.user_id, post_time, poster_ip, \
			enable_bbcode, p.attach, enable_html, enable_smilies, enable_sig, post_edit_time, \
			post_edit_count, status, pt.post_subject, pt.post_text, username, p.need_moderate \
			FROM jforum_posts p, jforum_posts_text pt, jforum_users u \
			WHERE p.post_id = pt.post_id \
			AND p.user_id = u.user_id \
			AND p.user_id = ? \
			AND p.need_moderate = 0 \
			AND forum_id IN(:fids:) \
			ORDER BY post_time DESC

PostModel.countUserPosts = SELECT COUNT(post_id) AS total FROM jforum_posts where user_id = ? AND forum_id IN (:fids:) AND need_moderate = 0

# ##########
# PollModel
# ##########
PollModel.lastGeneratedPollId = SELECT FIRST 1 'jforum_vote_desc_seq'.CURRVAL FROM jforum_vote_desc
PollModel.addNewPoll = INSERT INTO jforum_vote_desc (vote_id, topic_id, vote_text, vote_length, vote_start) VALUES (jforum_vote_desc_seq.NEXTVAL, ?, ?, ?, CURRENT)
		
# #############
# ForumModel
# #############
ForumModel.lastGeneratedForumId = SELECT FIRST 1 'jforum_forums_seq'.CURRVAL FROM jforum_forums
ForumModel.addNew = INSERT INTO jforum_forums (forum_id, categories_id, forum_name, forum_desc, forum_order, moderated) VALUES ('jforum_forums_seq'.NEXTVAL, ?, ?, ?, ?, ?)
ForumModel.countForumPosts = SELECT COUNT(post_id) FROM jforum_posts WHERE forum_id = ?
ForumModel.totalMessages = SELECT COUNT(post_id) as total_messages FROM jforum_posts
ForumModel.statsFirstPostTime = SELECT MIN(post_time) FROM jforum_posts WHERE post_time > "2000-01-01 00:00:00"
ForumModel.statsFirstRegisteredUserTime = SELECT MIN(user_regdate) FROM jforum_users WHERE user_regdate > "2000-01-01 00:00:00"

# #############
# TopicModel
# #############
TopicModel.selectAllByForumByLimit = SELECT FIRST #N# t.*, p.user_id AS last_user_id, p.post_time, 0 AS attach \
			FROM jforum_topics t, jforum_posts p \
			WHERE t.forum_id = ? \
			AND p.post_id = t.topic_last_post_id \
			AND p.need_moderate = 0 \
			ORDER BY t.topic_type DESC, t.topic_last_post_id DESC

TopicModel.selectRecentTopicsByLimit = SELECT FIRST #N# t.*, p.user_id AS last_user_id, p.post_time, 0 AS attach \
	FROM jforum_topics t, jforum_posts p \
	WHERE p.post_id = t.topic_last_post_id \
	AND p.need_moderate = 0 \
	ORDER BY topic_last_post_id DESC

TopicModel.selectByUserByLimit = SELECT FIRST #N# t.*, p.user_id AS last_user_id, p.post_time, 0 AS attach \
			FROM jforum_topics t, jforum_posts p \
			WHERE p.post_id = t.topic_last_post_id \
			AND t.user_id = ? \
			AND p.need_moderate = 0 \
			AND t.forum_id IN(:fids:) \
			ORDER BY t.topic_last_post_id DESC

TopicModel.lastGeneratedTopicId = SELECT FIRST 1 'jforum_topics_seq'.CURRVAL FROM jforum_topics
TopicModel.addNew = INSERT INTO jforum_topics (topic_id, forum_id, topic_title, user_id, topic_time, topic_first_post_id, topic_last_post_id, topic_type, moderated) \
	VALUES ('jforum_topics_seq'.NEXTVAL, ?, ?, ?, ?, ?, ?, ?, ?)
TopicModel.getTotalPosts = SELECT COUNT(post_id) AS total FROM jforum_posts WHERE topic_id = ? AND need_moderate = 0
TopicModel.countUserTopics = SELECT COUNT(p.topic_id) AS total FROM jforum_topics t, jforum_posts p WHERE t.user_id = ? AND t.forum_id IN (:fids:) AND p.post_id = t.topic_first_post_id AND p.need_moderate = 0
TopicModel.totalTopics = SELECT COUNT(topic_id) FROM jforum_topics

# #############
# SmiliesModel
# #############
SmiliesModel.addNew = INSERT INTO jforum_smilies (smilie_id, code, url, disk_name) VALUES ('jforum_smilies_seq'.NEXTVAL, ?, ?, ?)

# #####################
# PrivateMessagesModel
# #####################
PrivateMessagesModel.lastGeneratedPmId = SELECT FIRST 1 'jforum_privmsgs_seq'.CURRVAL FROM jforum_privmsgs
PrivateMessageModel.add = INSERT INTO jforum_privmsgs (privmsgs_id, privmsgs_type, privmsgs_subject, privmsgs_from_userid, \
	privmsgs_to_userid, privmsgs_date, privmsgs_enable_bbcode, privmsgs_enable_html, privmsgs_enable_smilies, \
	privmsgs_attach_sig ) \
	VALUES ('jforum_privmsgs_seq'.NEXTVAL, ?, ?, ?, ?, ?, ?, ?, ?, ? )

# #################
# UserSessionModel
# #################
UserSessionModel.add = INSERT INTO jforum_sessions (session_seq_id, session_id, session_user_id, session_start ) VALUES ('jforum_sessions_seq'.NEXTVAL, ?, ?, ?)

# ###########
# KarmaModel
# ###########
KarmaModel.add = INSERT INTO jforum_karma (karma_id, post_id, post_user_id, from_user_id, points, topic_id, rate_date) VALUES ('jforum_karma_seq'.NEXTVAL, ?, ?, ?, ?, ?, ?)
KarmaModel.userCanAddKarma = SELECT COUNT(karma_id) FROM jforum_karma WHERE post_id = ? AND from_user_id = ?
KarmaModel.getUserKarmaPoints = SELECT SUM(points) AS points, COUNT(post_id) AS votes, from_user_id \
	FROM jforum_karma WHERE post_user_id = ? GROUP BY from_user_id

# ##############
# BookmarkModel
# ##############
BookmarkModel.add = INSERT INTO jforum_bookmarks (bookmark_id, user_id, relation_id, relation_type, public_visible, title, description) VALUES ('jforum_bookmarks_seq'.NEXTVAL, ?, ?, ?, ?, ?, ?)

# ################
# AttachmentModel
# ################
AttachmentModel.addQuotaLimit = INSERT INTO jforum_quota_limit (quota_limit_id, quota_desc, quota_limit, quota_type) VALUES ('jforum_quota_limit_seq'.NEXTVAL, ?, ?, ?)
AttachmentModel.addExtensionGroup = INSERT INTO jforum_extension_groups (extension_group_id, name, allow, upload_icon, download_mode) VALUES ('jforum_extension_groups_seq'.NEXTVAL, ?, ?, ?, ?)
AttachmentModel.addExtension = INSERT INTO jforum_extensions (extension_id, extension_group_id, description, upload_icon, extension, allow) VALUES ('jforum_extensions_seq'.NEXTVAL, ?, ?, ?, ?, ?)
AttachmentModel.addAttachment = INSERT INTO jforum_attach (attach_id, post_id, privmsgs_id, user_id) VALUES ('jforum_attach_seq'.NEXTVAL, ?, ?, ?)
AttachmentModel.addAttachmentInfo = INSERT INTO jforum_attach_desc (attach_desc_id, attach_id, physical_filename, real_filename, description, \
	mimetype, filesize, upload_time, thumb, extension_id ) VALUES ('jforum_attach_desc_seq'.NEXTVAL, ?, ?, ?, ?, ?, ?, ?, ?, ?)
AttachmentModel.setGroupQuota = INSERT INTO jforum_attach_quota (attach_quota_id, group_id, quota_limit_id) VALUES ('jforum_attach_quota_seq'.NEXTVAL, ?, ?)
AttachmentModel.countPostAttachments = SELECT COUNT(attach_id) FROM jforum_attach WHERE post_id = ?
AttachmentModel.selectQuotaLimitByGroup = SELECT ql.quota_limit_id, ql.quota_desc, ql.quota_limit, ql.quota_type \
	FROM jforum_quota_limit ql, jforum_attach_quota atq \
	WHERE ql.quota_limit_id = atq.quota_limit_id \
	AND atq.group_id = ?

# ############
# SearchModel
# ############
SearchModel.insertTopicsIds = INSERT INTO jforum_search_results ( topic_id, session_id, search_time ) SELECT DISTINCT t.topic_id, :sid:, CURRENT YEAR TO SECOND FROM jforum_topics t, jforum_posts p \
	WHERE t.topic_id = p.topic_id AND t.forum_id IN(:fids:) \
	AND p.post_id IN (:posts:)
	
SearchModel.selectTopicData = INSERT INTO jforum_search_topics (search_topics_id, topic_id, forum_id, topic_title, user_id, topic_time, \
	topic_views, topic_status, topic_replies, topic_vote_id, topic_type, topic_first_post_id, topic_last_post_id, moderated, session_id, search_time) \
	SELECT 'jforum_search_topics_seq'.NEXTVAL, t.topic_id, t.forum_id, t.topic_title, t.user_id, t.topic_time, \
	t.topic_views, t.topic_status, t.topic_replies, t.topic_vote_id, t.topic_type, t.topic_first_post_id, t.topic_last_post_id, t.moderated, :sid:, CURRENT YEAR TO SECOND \
	FROM jforum_topics t, jforum_search_results s \
	WHERE t.topic_id = s.topic_id \
	AND s.session_id = :sid:
	
SearchModel.searchByTime = INSERT INTO jforum_search_results (topic_id, session_id, search_time) SELECT DISTINCT t.topic_id, :sid:, CURRENT YEAR TO SECOND FROM jforum_topics t, jforum_posts p \
	WHERE t.topic_id = p.topic_id \
	AND t.forum_id IN (:fids:) \
	AND p.post_time > ?

SearchModel.getPostsToIndex = SELECT FIRST #N# p.post_id, pt.post_text, pt.post_subject \
			FROM jforum_posts p, jforum_posts_text pt \
			WHERE p.post_id = pt.post_id \
			AND p.post_id BETWEEN ? AND ? \
			ORDER BY p.post_id ASC
SearchModel.insertWords = INSERT INTO jforum_search_words (word_id, word, word_hash) VALUES ('jforum_search_words_seq'.NEXTVAL, ?, ?)
SearchModel.howManyToIndex = SELECT COUNT(post_id) FROM jforum_posts WHERE post_time < ? AND post_id > ?

# #############
# SmiliesModel
# #############
SmiliesModel.lastGeneratedSmilieId = SELECT FIRST 1 'jforum_smilies_seq'.CURRVAL FROM jforum_smilies

# ##################
# PermissionControl
# ##################
PermissionControl.lastGeneratedRoleId = SELECT FIRST 1 'jforum_roles_seq'.CURRVAL FROM jforum_roles
PermissionControl.addGroupRole = INSERT INTO jforum_roles (role_id, group_id, name) VALUES ('jforum_roles_seq'.NEXTVAL, ?, ?)

# ##############
# CategoryModel
# ##############
CategoryModel.lastGeneratedCategoryId = SELECT FIRST 1 'jforum_categories_seq'.CURRVAL FROM jforum_categories

# ################
# AttachmentModel
# ################
AttachmentModel.lastGeneratedAttachmentId = SELECT FIRST 1 'jforum_attach_seq'.CURRVAL FROM jforum_attach

# #############
# BannerDAO
# #############
BannerDAO.addNew = INSERT INTO jforum_banner (banner_id, banner_name, banner_placement, banner_description, banner_clicks, banner_views, banner_url, banner_weight, \
	banner_active, banner_comment, banner_type, banner_width, banner_height) VALUES ('jforum_banner_seq'.NEXTVAL, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
BannerDAO.canDelete = SELECT COUNT(banner_id) AS total FROM jforum_banner WHERE banner_id = ?

# ###############
# BanlistModel
# ###############
BanlistModel.lastGeneratedBanlistId = SELECT FIRST 1 'jforum_banlist_seq'.CURRVAL FROM jforum_banlist
BanlistModel.insert = INSERT INTO jforum_banlist (banlist_id , user_id, banlist_ip, banlist_email) VALUES ('jforum_banlist_seq'.NEXTVAL, ?, ?, ?)