--
-- Table structure for table 'jforum_banlist'
--

CREATE SEQUENCE jforum_banlist_seq;
CREATE TABLE jforum_banlist (
  banlist_id INTEGER DEFAULT 'jforum_banlist_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  user_id INTEGER DEFAULT 0,
  banlist_ip VARCHAR(20),
  banlist_email VARCHAR(255)
);
CREATE INDEX idx_banlist_user ON jforum_banlist(user_id);
CREATE INDEX idx_banlist_ip ON jforum_banlist(banlist_ip);
CREATE INDEX idx_banlist_email ON jforum_banlist(banlist_email);

--
-- Table structure for table 'jforum_categories'
--

CREATE SEQUENCE jforum_categories_seq;
CREATE SEQUENCE jforum_categories_order_seq;
CREATE TABLE jforum_categories (
  categories_id INTEGER DEFAULT 'jforum_categories_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  title VARCHAR(100) DEFAULT '' NOT NULL,
  display_order INTEGER DEFAULT 0 NOT NULL,
  moderated INTEGER DEFAULT 0
);

--
-- Table structure for table 'jforum_config'
--

CREATE SEQUENCE jforum_config_seq;
CREATE TABLE jforum_config (
  config_name VARCHAR(255) NOT NULL DEFAULT '',
  config_value VARCHAR(255) NOT NULL DEFAULT '',
  config_id int DEFAULT 'jforum_config_seq'.NEXTVAL NOT NULL PRIMARY KEY
);

--
-- Table structure for table 'jforum_forums'
--

CREATE SEQUENCE jforum_forums_seq;
CREATE TABLE jforum_forums (
  forum_id INTEGER DEFAULT 'jforum_forums_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  categories_id INTEGER DEFAULT 1 NOT NULL,
  forum_name VARCHAR(150) DEFAULT '' NOT NULL,
  forum_desc VARCHAR(255) DEFAULT NULL,
  forum_order INTEGER DEFAULT 1,
  forum_topics INTEGER DEFAULT 0 NOT NULL,
  forum_last_post_id INTEGER DEFAULT 0 NOT NULL,
  moderated INTEGER DEFAULT 0
);
CREATE INDEX idx_forums_categories_id ON jforum_forums(categories_id);

--
-- Table structure for table 'jforum_forums_watch'
--
CREATE TABLE jforum_forums_watch (
  forum_id INTEGER NOT NULL,
  user_id INTEGER NOT NULL,
  is_read INTEGER DEFAULT 1
);
CREATE INDEX idx_fw_forum ON jforum_forums_watch(forum_id);
CREATE INDEX idx_fw_user ON jforum_forums_watch(user_id);

--
-- Table structure for table 'jforum_groups'
--

CREATE SEQUENCE jforum_groups_seq;
CREATE TABLE jforum_groups (
  group_id INTEGER DEFAULT 'jforum_groups_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  group_name VARCHAR(40) DEFAULT '' NOT NULL,
  group_description VARCHAR(255) DEFAULT NULL,
  parent_id INTEGER DEFAULT 0
);


CREATE TABLE jforum_user_groups (
	group_id INT NOT NULL,
	user_id INT NOT NULL
);
CREATE INDEX idx_ug_group ON jforum_user_groups(group_id);
CREATE INDEX idx_ug_user ON jforum_user_groups(user_id);

--
-- Table structure for table 'jforum_roles'
--

CREATE SEQUENCE jforum_roles_seq;
CREATE TABLE jforum_roles (
  role_id INT DEFAULT 'jforum_roles_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  group_id INTEGER DEFAULT 0,
  name VARCHAR(255) NOT NULL
);
CREATE INDEX idx_roles_group ON jforum_roles(group_id);
CREATE INDEX idx_roles_name ON jforum_roles(name);

--
-- Table structure for table 'jforum_role_values'
--
CREATE TABLE jforum_role_values (
  role_id INT NOT NULL,
  role_value VARCHAR(255)
);
CREATE INDEX idx_rv_role ON jforum_role_values(role_id);

--
-- Table structure for table 'jforum_posts'
--

CREATE SEQUENCE jforum_posts_seq;
CREATE TABLE jforum_posts (
  post_id INTEGER DEFAULT 'jforum_posts_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  topic_id INTEGER DEFAULT 0 NOT NULL,
  forum_id INTEGER DEFAULT 0 NOT NULL,
  user_id INTEGER DEFAULT 0 NOT NULL,
  post_time DATETIME YEAR TO SECOND DEFAULT NULL,
  poster_ip VARCHAR(15) DEFAULT NULL,
  enable_bbcode INTEGER DEFAULT 1 NOT NULL,
  enable_html INTEGER DEFAULT 1 NOT NULL,
  enable_smilies INTEGER DEFAULT 1 NOT NULL,
  enable_sig INTEGER DEFAULT 1 NOT NULL,
  post_edit_time DATETIME YEAR TO SECOND DEFAULT NULL,
  post_edit_count INTEGER DEFAULT 0 NOT NULL,
  status INTEGER DEFAULT 1,
  attach INTEGER DEFAULT 0,
  need_moderate INTEGER DEFAULT 0
);
CREATE INDEX idx_posts_user ON jforum_posts(user_id);
CREATE INDEX idx_posts_topic ON jforum_posts(topic_id);
CREATE INDEX idx_posts_forum ON jforum_posts(forum_id);

--
-- Table structure for table 'jforum_posts_text'
--
CREATE TABLE jforum_posts_text (
	post_id INTEGER NOT NULL PRIMARY KEY,
	post_text TEXT,
	post_subject VARCHAR(100) DEFAULT NULL
);

--
-- Table structure for table 'jforum_privmsgs'
--

CREATE SEQUENCE jforum_privmsgs_seq;
CREATE TABLE jforum_privmsgs (
  privmsgs_id INTEGER DEFAULT 'jforum_privmsgs_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  privmsgs_type INTEGER DEFAULT 0 NOT NULL,
  privmsgs_subject VARCHAR(255) DEFAULT '' NOT NULL,
  privmsgs_from_userid INTEGER DEFAULT 0 NOT NULL,
  privmsgs_to_userid INTEGER DEFAULT 0 NOT NULL,
  privmsgs_date DATETIME YEAR TO SECOND DEFAULT CURRENT YEAR TO SECOND NOT NULL,
  privmsgs_ip VARCHAR(8) DEFAULT '' NOT NULL,
  privmsgs_enable_bbcode INTEGER DEFAULT 1 NOT NULL,
  privmsgs_enable_html INTEGER DEFAULT 0 NOT NULL,
  privmsgs_enable_smilies INTEGER DEFAULT 1 NOT NULL,
  privmsgs_attach_sig INTEGER DEFAULT 1 NOT NULL
);

CREATE TABLE jforum_privmsgs_text (
	privmsgs_id INTEGER NOT NULL,
	privmsgs_text TEXT
);
CREATE INDEX idx_pm_text_id ON jforum_privmsgs_text (privmsgs_id);

--
-- Table structure for table 'jforum_ranks'
--

CREATE SEQUENCE jforum_ranks_seq;
CREATE TABLE jforum_ranks (
  rank_id INTEGER DEFAULT 'jforum_ranks_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  rank_title VARCHAR(50) DEFAULT '' NOT NULL,
  rank_min INTEGER DEFAULT 0 NOT NULL,
  rank_special INTEGER DEFAULT NULL,
  rank_image VARCHAR(255) DEFAULT NULL
);

--
-- Table structure for table 'jforum_sessions'
--

CREATE TABLE jforum_sessions (
  session_id VARCHAR(150) DEFAULT '' NOT NULL,
  session_user_id INTEGER DEFAULT 0 NOT NULL,
  session_start DATETIME YEAR TO SECOND DEFAULT CURRENT YEAR TO SECOND NOT NULL,
  session_time int DEFAULT 0 NOT NULL,
  session_ip VARCHAR(8) DEFAULT '' NOT NULL,
  session_page INTEGER DEFAULT 0 NOT NULL,
  session_logged_int INTEGER DEFAULT NULL
);

--
-- Table structure for table 'jforum_smilies'
--

CREATE SEQUENCE jforum_smilies_seq;
CREATE TABLE jforum_smilies (
  smilie_id INTEGER DEFAULT 'jforum_smilies_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  code VARCHAR(50) DEFAULT '' NOT NULL,
  url VARCHAR(100) DEFAULT NULL,
  disk_name VARCHAR(255)
);

--
-- Table structure for table 'jforum_themes'
--

CREATE SEQUENCE jforum_themes_seq;
CREATE TABLE jforum_themes (
  themes_id INTEGER DEFAULT 'jforum_themes_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  template_name VARCHAR(30) DEFAULT '' NOT NULL,
  style_name VARCHAR(30) DEFAULT '' NOT NULL
);

--
-- Table structure for table 'jforum_topics'
--

CREATE SEQUENCE jforum_topics_seq;
CREATE TABLE jforum_topics (
  topic_id INTEGER DEFAULT 'jforum_topics_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  forum_id INTEGER DEFAULT 0 NOT NULL,
  topic_title VARCHAR(100) DEFAULT '' NOT NULL,
  user_id INTEGER DEFAULT 0 NOT NULL,
  topic_time DATE TIME YEAR TO SECOND DEFAULT CURRENT YEAR TO SECOND NOT NULL,
  topic_views INTEGER DEFAULT 1,
  topic_replies INTEGER DEFAULT 0,
  topic_status INTEGER DEFAULT 0,
  topic_vote_id INTEGER DEFAULT 0,
  topic_type INTEGER DEFAULT 0,
  topic_first_post_id INTEGER DEFAULT 0,
  topic_last_post_id INTEGER DEFAULT 0 NOT NULL,
  moderated INTEGER DEFAULT 0
);
CREATE INDEX idx_topics_forum ON jforum_topics(forum_id);
CREATE INDEX idx_topics_user ON jforum_topics(user_id);
CREATE INDEX idx_topics_fp ON jforum_topics(topic_first_post_id);
CREATE INDEX idx_topics_lp ON jforum_topics(topic_last_post_id);

--
-- Table structure for table 'jforum_topics_watch'
--

CREATE TABLE jforum_topics_watch (
  topic_id INTEGER DEFAULT 0 NOT NULL,
  user_id INTEGER DEFAULT 0 NOT NULL,
  is_read INTEGER DEFAULT 0 NOT NULL
);
CREATE INDEX idx_tw_topic ON jforum_topics_watch(topic_id);
CREATE INDEX idx_tw_user ON jforum_topics_watch(user_id);

--
-- Table structure for table 'jforum_users'
--

CREATE SEQUENCE jforum_users_seq;
CREATE TABLE jforum_users (
  user_id INTEGER DEFAULT 'jforum_users_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  user_active INTEGER DEFAULT NULL,
  username VARCHAR(50) DEFAULT '' NOT NULL,
  user_password VARCHAR(32) DEFAULT '' NOT NULL,
  user_session_time int DEFAULT 0 NOT NULL,
  user_session_page INTEGER DEFAULT 0 NOT NULL,
  user_lastvisit DATETIME YEAR TO SECOND DEFAULT CURRENT YEAR TO SECOND NOT NULL,
  user_regdate DATETIME YEAR TO SECOND DEFAULT CURRENT YEAR TO SECOND NOT NULL,
  user_level INTEGER DEFAULT NULL,
  user_posts INTEGER DEFAULT 0 NOT NULL,
  user_timezone VARCHAR(5) DEFAULT '' NOT NULL,
  user_style INTEGER DEFAULT NULL,
  user_lang VARCHAR(255) DEFAULT NULL,
  user_dateformat VARCHAR(20) DEFAULT '%d/%M/%Y %H:%i' NOT NULL,
  user_new_privmsg INTEGER DEFAULT 0 NOT NULL,
  user_unread_privmsg INTEGER DEFAULT 0 NOT NULL,
  user_last_privmsg DATETIME YEAR TO SECOND DEFAULT NULL,
  user_emailtime DATETIME YEAR TO SECOND DEFAULT NULL,
  user_viewemail INTEGER DEFAULT 0,
  user_attachsig INTEGER DEFAULT 1,
  user_allowhtml INTEGER DEFAULT 0,
  user_allowbbcode INTEGER DEFAULT 1,
  user_allowsmilies INTEGER DEFAULT 1,
  user_allowavatar INTEGER DEFAULT 1,
  user_allow_pm INTEGER DEFAULT 1,
  user_allow_viewonline INTEGER DEFAULT 1,
  user_notify INTEGER DEFAULT 1,
  user_notify_pm INTEGER DEFAULT 1,
  user_popup_pm INTEGER DEFAULT 1,
  rank_id INTEGER DEFAULT 1,
  user_avatar VARCHAR(100) DEFAULT NULL,
  user_avatar_type INTEGER DEFAULT 0 NOT NULL,
  user_email VARCHAR(255) DEFAULT '' NOT NULL,
  user_icq VARCHAR(15) DEFAULT NULL,
  user_website VARCHAR(255) DEFAULT NULL,
  user_from VARCHAR(100) DEFAULT NULL,
  user_sig TEXT,
  user_sig_bbcode_uid VARCHAR(10) DEFAULT NULL,
  user_aim VARCHAR(255) DEFAULT NULL,
  user_yim VARCHAR(255) DEFAULT NULL,
  user_msnm VARCHAR(255) DEFAULT NULL,
  user_occ VARCHAR(100) DEFAULT NULL,
  user_interests VARCHAR(255) DEFAULT NULL,
  user_biography TEXT DEFAULT NULL,
  user_actkey VARCHAR(32) DEFAULT NULL,
  gender CHAR(1) DEFAULT NULL,
  themes_id INTEGER DEFAULT NULL,
  deleted INTEGER DEFAULT NULL,
  user_viewonline INTEGER DEFAULT 1,
  security_hash VARCHAR(32),
  user_karma NUMERIC(10,2),
  user_authhash VARCHAR(32),
  user_notify_always INTEGER DEFAULT 0,
  user_notify_text INTEGER DEFAULT 0
);


--
-- Table structure for table 'jforum_vote_desc'
--

CREATE SEQUENCE jforum_vote_desc_seq;
CREATE TABLE jforum_vote_desc (
  vote_id INTEGER DEFAULT 'jforum_vote_desc_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  topic_id INTEGER DEFAULT 0 NOT NULL,
  vote_text VARCHAR(255) DEFAULT '' NOT NULL,
  vote_start TIMESTAMP NOT NULL,
  vote_length INTEGER DEFAULT 0 NOT NULL
);

--
-- Table structure for table 'jforum_vote_results'
--

CREATE TABLE jforum_vote_results (
  vote_id INTEGER DEFAULT 0 NOT NULL,
  vote_option_id INTEGER DEFAULT 0 NOT NULL,
  vote_option_text VARCHAR(255) DEFAULT '' NOT NULL,
  vote_result INTEGER DEFAULT 0 NOT NULL
);

--
-- Table structure for table 'jforum_vote_voters'
--

CREATE TABLE jforum_vote_voters (
  vote_id INTEGER DEFAULT 0 NOT NULL,
  vote_user_id INTEGER DEFAULT 0 NOT NULL,
  vote_user_ip VARCHAR(15) DEFAULT '' NOT NULL
);

--
-- Table structure for table 'jforum_words'
--

CREATE SEQUENCE jforum_words_seq;
CREATE TABLE jforum_words (
  word_id INTEGER DEFAULT 'jforum_words_seq'.NEXTVAL NOT NULL PRIMARY KEY,
  word VARCHAR(100) DEFAULT '' NOT NULL,
  replacement VARCHAR(100) DEFAULT '' NOT NULL
);

--
-- Table structure for table 'jforum_search_words'
--
CREATE SEQUENCE jforum_search_words_seq;
CREATE TABLE jforum_search_words (
  word_id INT NOT NULL DEFAULT 'jforum_search_words_seq'.NEXTVAL PRIMARY KEY,
  word VARCHAR(100) NOT NULL,
  word_hash INT
);
CREATE INDEX idx_sw_word ON jforum_search_words(word);
CREATE INDEX idx_sw_hash ON jforum_search_words(word_hash);

-- 
-- Table structure for table 'jforum_search_wordmatch'
--
CREATE TABLE jforum_search_wordmatch (
  post_id INT NOT NULL,
  word_id INT NOT NULL,
  title_match INTEGER DEFAULT 0
);
CREATE INDEX idx_swm_post ON jforum_search_wordmatch(post_id);
CREATE INDEX idx_swm_word ON jforum_search_wordmatch(word_id);
CREATE INDEX idx_swm_title ON jforum_search_wordmatch(title_match);

--
-- Table structure for table 'jforum_search_results'
--
CREATE TABLE jforum_search_results (
  topic_id INT NOT NULL,
  session_id VARCHAR(150),
  search_time DATETIME YEAR TO SECOND
);
CREATE INDEX idx_sr_topic ON jforum_search_results(topic_id);
CREATE INDEX idx_sr_session ON jforum_search_results(session_id);

CREATE TABLE jforum_search_topics (
  topic_id INTEGER NOT NULL,
  forum_id INTEGER DEFAULT 0 NOT NULL,
  topic_title VARCHAR(100) DEFAULT '' NOT NULL,
  user_id INTEGER DEFAULT 0 NOT NULL,
  topic_time DATETIME YEAR TO SECOND DEFAULT CURRENT YEAR TO SECOND NOT NULL,
  topic_views INTEGER DEFAULT 1,
  topic_replies INTEGER DEFAULT 0,
  topic_status INTEGER DEFAULT 0,
  topic_vote_id INTEGER DEFAULT 0,
  topic_type INTEGER DEFAULT 0,
  topic_first_post_id INTEGER DEFAULT 0,
  topic_last_post_id INTEGER DEFAULT 0 NOT NULL,
  moderated INTEGER DEFAULT 0,
  session_id VARCHAR(150),
  search_time DATETIME YEAR TO SECOND
);

CREATE INDEX idx_st_topic ON jforum_search_topics(topic_id);
CREATE INDEX idx_st_forum ON jforum_search_topics(forum_id);
CREATE INDEX idx_st_user ON jforum_search_topics(user_id);
CREATE INDEX idx_st_fp ON jforum_search_topics(topic_first_post_id);
CREATE INDEX idx_st_lp ON jforum_search_topics(topic_last_post_id);
CREATE INDEX idx_st_session ON jforum_search_topics(session_id);

--
-- Table structure for table 'jforum_karma'
--
CREATE SEQUENCE jforum_karma_seq;
CREATE TABLE jforum_karma (
	karma_id INTEGER DEFAULT 'jforum_karma_seq'.NEXTVAL NOT NULL PRIMARY KEY,
	post_id INTEGER NOT NULL,
	topic_id INTEGER NOT NULL,
	post_user_id INTEGER NOT NULL,
	from_user_id INTEGER NOT NULL,
	points INTEGER NOT NULL,
	rate_date DATETIME YEAR TO SECOND DEFAULT NULL
);

CREATE INDEX idx_krm_post ON jforum_karma(post_id);
CREATE INDEX idx_krm_topic ON jforum_karma(topic_id);
CREATE INDEX idx_krm_user ON jforum_karma(post_user_id);
CREATE INDEX idx_krm_from ON jforum_karma(from_user_id);

--
-- Table structure for table 'jforum_bookmark'
--
CREATE SEQUENCE jforum_bookmarks_seq;
CREATE TABLE jforum_bookmarks (
	bookmark_id INTEGER DEFAULT 'jforum_bookmarks_seq'.NEXTVAL NOT NULL PRIMARY KEY,
	user_id INTEGER NOT NULL,
	relation_id INTEGER NOT NULL,
	relation_type INTEGER NOT NULL,
	public_visible INTEGER DEFAULT 1,
	title VARCHAR(255),
	description VARCHAR(255)
);

CREATE INDEX idx_bok_user ON jforum_bookmarks(user_id);
CREATE INDEX idx_bok_rel ON jforum_bookmarks(relation_id);

-- 
-- Table structure for table 'jforum_quota_limit'
--
CREATE SEQUENCE jforum_quota_limit_seq;
CREATE TABLE jforum_quota_limit (
	quota_limit_id INTEGER DEFAULT 'jforum_quota_limit_seq'.NEXTVAL NOT NULL PRIMARY KEY,
	quota_desc VARCHAR(50) NOT NULL,
	quota_limit INTEGER NOT NULL,
	quota_type INTEGER DEFAULT 1
);

--
-- Table structure for table 'jforum_extension_groups'
--
CREATE SEQUENCE jforum_extension_groups_seq;
CREATE TABLE jforum_extension_groups (
	extension_group_id INTEGER DEFAULT 'jforum_extension_groups_seq'.NEXTVAL NOT NULL PRIMARY KEY,
	name VARCHAR(100) NOT NULL,
	allow INTEGER DEFAULT 1, 
	upload_icon VARCHAR(100),
	download_mode INTEGER DEFAULT 1
);

-- 
-- Table structure for table 'jforum_extensions'
--
CREATE SEQUENCE jforum_extensions_seq;
CREATE TABLE jforum_extensions (
	extension_id INTEGER DEFAULT ('jforum_extensions_seq').NEXTVAL NOT NULL PRIMARY KEY,
	extension_group_id INTEGER NOT NULL,
	description VARCHAR(100),
	upload_icon VARCHAR(100),
	extension VARCHAR(10),
	allow INTEGER DEFAULT 1
);

CREATE INDEX idx_ext_group ON jforum_extensions(extension_group_id);
CREATE INDEX idx_ext_ext ON jforum_extensions(extension);

--
-- Table structure for table 'jforum_attach'
--
CREATE SEQUENCE jforum_attach_seq;
CREATE TABLE jforum_attach (
	attach_id INTEGER DEFAULT 'jforum_attach_seq'.NEXTVAL NOT NULL PRIMARY KEY,
	post_id INTEGER,
	privmsgs_id INTEGER,
	user_id INTEGER NOT NULL
);

CREATE INDEX idx_att_post ON jforum_attach(post_id);
CREATE INDEX idx_att_priv ON jforum_attach(privmsgs_id);
CREATE INDEX idx_att_user ON jforum_attach(user_id);

-- 
-- Table structure for table 'jforum_attach_desc'
--
CREATE SEQUENCE jforum_attach_desc_seq;
CREATE TABLE jforum_attach_desc (
	attach_desc_id INTEGER DEFAULT 'jforum_attach_desc_seq'.NEXTVAL NOT NULL PRIMARY KEY,
	attach_id INTEGER NOT NULL,
	physical_filename VARCHAR(255) NOT NULL,
	real_filename VARCHAR(255) NOT NULL,
	download_count INTEGER,
	description VARCHAR(255),
	mimetype VARCHAR(50),
	filesize NUMERIC(20),
	upload_time DATE,
	thumb INTEGER DEFAULT 0,
	extension_id INTEGER
);

CREATE INDEX idx_att_d_att ON jforum_attach_desc(attach_id);
CREATE INDEX idx_att_d_ext ON jforum_attach_desc(extension_id);

--
-- Table structure for table 'jforum_attach_quota'
--
CREATE SEQUENCE jforum_attach_quota_seq;
CREATE TABLE jforum_attach_quota (
	attach_quota_id INTEGER DEFAULT 'jforum_attach_quota_seq'.NEXTVAL NOT NULL PRIMARY KEY,
	group_id INTEGER NOT NULL,
	quota_limit_id INTEGER NOT NULL
);

CREATE INDEX idx_aq_group ON jforum_attach_quota(group_id);
CREATE INDEX idx_aq_ql ON jforum_attach_quota(quota_limit_id);

--
-- Table structure for table 'jforum_banner'
--
CREATE SEQUENCE jforum_banner_seq;
CREATE TABLE jforum_banner (
	banner_id INTEGER DEFAULT 'jforum_banner_seq'.NEXTVAL NOT NULL PRIMARY KEY,
	banner_name VARCHAR(90),
	banner_placement INTEGER DEFAULT 0 NOT NULL,
	banner_description VARCHAR(250),
	banner_clicks INTEGER DEFAULT 0 NOT NULL,
	banner_views INTEGER DEFAULT 0 NOT NULL,
	banner_url VARCHAR(250),
	banner_weight INTEGER DEFAULT 50 NOT NULL,
	banner_active INTEGER DEFAULT 0 NOT NULL,
	banner_comment VARCHAR(250),
	banner_type INTEGER DEFAULT 0 NOT NULL,
	banner_width INTEGER DEFAULT 0 NOT NULL,
	banner_height INTEGER DEFAULT 0 NOT NULL
);
