/*
 * Copyright (c) LINAGORA
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, 
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 * 
 * 1) Redistributions of source code must retain the above 
 * copyright notice, this list of conditions and the 
 * following  disclaimer.
 * 2)  Redistributions in binary form must reproduce the 
 * above copyright notice, this list of conditions and 
 * the following disclaimer in the documentation and/or 
 * other materials provided with the distribution.
 * 3) Neither the name of "Rafael Steil" nor 
 * the names of its contributors may be used to endorse 
 * or promote products derived from this software without 
 * specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT 
 * HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, 
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
 * THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER 
 * IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE
 * 
 * Created on 27.03.2007 
 */
package net.jforum.dao.informix;

import net.jforum.dao.PostDAO;
import net.jforum.dao.ScheduledSearchIndexerDAO;
import net.jforum.dao.SearchDAO;
import net.jforum.dao.TopicDAO;
import net.jforum.dao.UserDAO;
import net.jforum.dao.UserRequestDAO;
import net.jforum.dao.generic.GenericDataAccessDriver;

/**
 * @author Jonathan Clarke <jclarke@linagora.com>
 */
public class InformixDataAccessDriver extends GenericDataAccessDriver 
{
	private static PostDAO postDao = new InformixPostDAO();
	private static UserDAO userDao = new InformixUserDAO();
	private static TopicDAO topicDao = new InformixTopicDAO();
	private static ScheduledSearchIndexerDAO scheduledSearchIndexerDao = new InformixScheduledSearchIndexerDAO();
	private static UserRequestDAO userRequestDao = new InformixUserRequestDAO();
	private static SearchDAO searchDao = new InformixSearchDAO();

	/**
	 * @see net.jforum.dao.DataAccessDriver#newPostDAO()
	 */
	public PostDAO newPostDAO() {
		return postDao;
	}
	
	/**
	 * @see net.jforum.dao.DataAccessDriver#newUserDAO()
	 */
	public UserDAO newUserDAO() {
		return userDao;
	}

	/**
	 * @see net.jforum.dao.DataAccessDriver#newUserDAO()
	 */
	public TopicDAO newTopicDAO() {
		return topicDao;
	}

	/**
	 * @see net.jforum.dao.DataAccessDriver#newUserDAO()
	 */
	public ScheduledSearchIndexerDAO newScheduledSearchIndexerDAO() {
		return scheduledSearchIndexerDao;
	}
	
	/**
	 * @see net.jforum.dao.DataAccessDriver#newInformixUserRequestDAO()
	 */
	public UserRequestDAO newUserRequestDAO() {
		return userRequestDao;
	}

	/**
	 * @see net.jforum.dao.DataAccessDriver#newInformixSearchDAO()
	 */
	public SearchDAO newSearchDAO() {
		return searchDao;
	}
	
}