/*
 * Copyright (c) LINAGORA
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, 
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 * 
 * 1) Redistributions of source code must retain the above 
 * copyright notice, this list of conditions and the 
 * following  disclaimer.
 * 2)  Redistributions in binary form must reproduce the 
 * above copyright notice, this list of conditions and 
 * the following disclaimer in the documentation and/or 
 * other materials provided with the distribution.
 * 3) Neither the name of "Rafael Steil" nor 
 * the names of its contributors may be used to endorse 
 * or promote products derived from this software without 
 * specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT 
 * HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, 
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
 * THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER 
 * IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE
 * 
 * Created on 27.03.2007
 */
package net.jforum.dao.informix;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;

import net.jforum.JForumExecutionContext;
import net.jforum.dao.generic.GenericUserRequestDAO;
import net.jforum.entities.UserRequest;
import net.jforum.exceptions.DatabaseException;
import net.jforum.util.DbUtils;
import net.jforum.util.preferences.SystemGlobals;

/**
 * @author Jonathan Clarke <jclarke@linagora.com>
 */
public class InformixUserRequestDAO extends GenericUserRequestDAO
{
	/**
	 * @see net.jforum.dao.UserRequestDAO#selectAll(int, int, int)
	 */
	public Map selectAllByForum(int forumId, int startFrom, int count) {
		PreparedStatement p = null;
		ResultSet rs = null;

		try {
			if (count > 0) {
				String sql = SystemGlobals.getSql("UserRequestModel.selectAllByForumByLimit");
				sql = sql.replaceAll("#N#", String.valueOf(startFrom + count));
				
				p = JForumExecutionContext.getConnection().prepareStatement(SystemGlobals.getSql(sql));
				p.setInt(1, forumId);
				p.setInt(2, startFrom);
				p.setInt(3, count);
				
				// jump over first unwanted records
				for (int i=1; i < startFrom; i++) rs.next();

			}
			else {
				p = JForumExecutionContext.getConnection()
						.prepareStatement(SystemGlobals.getSql("UserRequestModel.selectAllByForum"));
			}

			rs = p.executeQuery();

			return this.processSelectAll(rs);
		}
		catch (SQLException e) {
			throw new DatabaseException(e);
		}
		finally {
			DbUtils.close(rs, p);
		}
	}

}